/*
 *  tex2math.js
 *  
 *  Part of the jsMath package for mathematics on the web.
 *
 *  This file is a plugin that searches text wthin a web page
 *  for \(...\), \[...\], $...$ and $$...$$ and converts them to
 *  the appropriate <SPAN CLASS="math">...</SPAN> or
 *  <DIV CLASS="math">...</DIV> tags.
 *
 *  ---------------------------------------------------------------------
 *
 *  jsMath is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  jsMath is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with jsMath; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */



jsMath.Add(jsMath,{
  
  ConvertTeX: function (element) {this.ConvertMath("TeX2math",element)},
  ConvertLaTeX: function (element) {this.ConvertMath("LaTeX2math",element)},
  
  ConvertMath: function (method,element,recurse) {
    if (!element) {
      if (recurse) return;
      element = document.body;
    }
    if (typeof(element) == 'string')
      {element = document.getElementById(element)}

    if (element.nodeName == '#text') {
      if (!element.tagName || !element.tagName.match(/^(SCRIPT|STYLE|TEXTAREA)$/i)) {
        var call = this[method];
        call(element);
      }
    } else {
      this.ConvertMath(method,element.firstChild,1);
    }
    if (recurse) this.ConvertMath(method,element.nextSibling,1);
  },
  
  TeX2math: function (element) {
    var pattern = /\\\((([^\\]|\\.)*)\\\)|\\\[(([^\\]|\\.)*)\\\]|(\$\$?)([^$]*)\5/;
    var text; var result;
    while (result = pattern.exec(element.nodeValue.replace(/\n/g,' '))) {
      if (text = result[1] || result[3] || result[6]) {
        var type = result[0].substr(0,2);
        type = (type == '\\[' || type == '$$')? "div" : "span";
        var tag = document.createElement(type);
        var math = element.splitText(result.index);
        element = math.splitText(result[0].length);
        math.parentNode.replaceChild(tag,math);
        tag.className = "math";
        tag.innerHTML = text;
      } else if (result[0] == '$$') return;
    }
  },
  
  LaTeX2math: function (element) {
    var pattern = /\\\((([^\\]|\\.)*)\\\)|\\\[(([^\\]|\\.)*)\\\]/;
    var text; var result;
    while (result = pattern.exec(element.nodeValue.replace(/\n/g,' '))) {
      if (text = result[1] || result[3]) {
        var type = result[0].substr(0,2);
        type = (type == '\\[')? "div" : "span";
        var tag = document.createElement(type);
        var math = element.splitText(result.index);
        element = math.splitText(result[0].length);
        math.parentNode.replaceChild(tag,math);
        tag.className = "math";
        tag.innerHTML = text;
      }
    }
  }

});
